@@ -42,7 +42,7 @@ class Resource(models.BaseResource):
     endpoint = '/jobs/'
 
     @resources.command
-    @click.option('--job-template', type=int)
+    @click.option('--job-template', type=types.Related('job_template'))
     @click.option('--monitor', is_flag=True, default=False,
                   help='If sent, immediately calls `job monitor` on the newly '
                        'launched job rather than exiting with a success.')
@@ -68,12 +68,14 @@ class Resource(models.BaseResource):
         # Update the job data by adding an automatically-generated job name,
         # and removing the ID.
         data = copy(jt)
-        data.pop('id')
+        data['job_template'] = data.pop('id')
         data['name'] = '%s [invoked via. Tower CLI]' % data['name']
 
         # If the job template requires prompting for extra variables,
         # do so (unless --no-input is set).
         if extra_vars:
+            if hasattr(extra_vars, 'read'):
+                extra_vars = extra_vars.read()
             data['extra_vars'] = extra_vars
         elif data.pop('ask_variables_on_launch', False) and not no_input:
             initial = data['extra_vars']
